@@ -48,15 +48,15 @@ module Browser
     def quality
       @quality ||= begin
         Float(quality_value || 1.0)
-                   rescue ArgumentError
-                     0.1
+      rescue ArgumentError
+        0.1
       end
     end
 
     private def quality_value
       qvalue = part[/;q=([\d.]+)/, 1]
-      qvalue = qvalue =~ /\A0\.0?\z/ ? "0.0" : qvalue
-      qvalue = qvalue.gsub(/\.+/, ".") if qvalue
+      qvalue = "0.0" if /\A0\.0?\z/.match?(qvalue)
+      qvalue = qvalue.squeeze(".") if qvalue
       qvalue
     end
   end
