@@ -26,7 +26,7 @@ module Browser
       end
     end
 
-    alias_method :to_a, :meta
+    alias to_a meta
 
     # Return meta representation as string.
     def to_s
@@ -59,13 +59,13 @@ module Browser
 
     # Detect if browser is Microsoft Internet Explorer.
     def ie?(expected_version = nil)
-      InternetExplorer.new(ua).match? &&
+      instance_of?(InternetExplorer) &&
         detect_version?(full_version, expected_version)
     end
 
     # Detect if browser is Microsoft Edge.
     def edge?(expected_version = nil)
-      Edge.new(ua).match? && detect_version?(full_version, expected_version)
+      instance_of?(Edge) && detect_version?(full_version, expected_version)
     end
 
     def compatibility_view?
@@ -82,32 +82,32 @@ module Browser
 
     # Detect if browser is Instagram.
     def instagram?(expected_version = nil)
-      Instagram.new(ua).match? &&
+      instance_of?(Instagram) &&
         detect_version?(full_version, expected_version)
     end
 
     # Detect if browser is Snapchat.
     def snapchat?(expected_version = nil)
-      Snapchat.new(ua).match? &&
+      instance_of?(Snapchat) &&
         detect_version?(full_version, expected_version)
     end
 
     # Detect if browser if Facebook.
     def facebook?(expected_version = nil)
-      Facebook.new(ua).match? &&
+      instance_of?(Facebook) &&
         detect_version?(full_version, expected_version)
     end
 
     # Detect if browser is Otter.
     def otter?(expected_version = nil)
-      Otter.new(ua).match? &&
+      instance_of?(Otter) &&
         detect_version?(full_version, expected_version)
     end
 
     # Detect if browser is WebKit-based.
     def webkit?(expected_version = nil)
       ua.match?(/AppleWebKit/i) &&
-        (!edge? || Edge.new(ua).chrome_based?) &&
+        (!edge? || chromium_based?) &&
         detect_version?(webkit_full_version, expected_version)
     end
 
@@ -124,13 +124,13 @@ module Browser
 
     # Detect if browser is PhantomJS
     def phantom_js?(expected_version = nil)
-      PhantomJS.new(ua).match? &&
+      instance_of?(PhantomJS) &&
         detect_version?(full_version, expected_version)
     end
 
     # Detect if browser is Safari.
     def safari?(expected_version = nil)
-      Safari.new(ua).match? && detect_version?(full_version, expected_version)
+      instance_of?(Safari) && detect_version?(full_version, expected_version)
     end
 
     def safari_webapp_mode?
@@ -139,55 +139,55 @@ module Browser
 
     # Detect if browser is Firefox.
     def firefox?(expected_version = nil)
-      Firefox.new(ua).match? && detect_version?(full_version, expected_version)
+      instance_of?(Firefox) && detect_version?(full_version, expected_version)
     end
 
     # Detect if browser is Chrome.
     def chrome?(expected_version = nil)
-      Chrome.new(ua).match? && detect_version?(full_version, expected_version)
+      instance_of?(Chrome) && detect_version?(full_version, expected_version)
     end
 
     # Detect if browser is Opera.
     def opera?(expected_version = nil)
-      Opera.new(ua).match? && detect_version?(full_version, expected_version)
+      instance_of?(Opera) && detect_version?(full_version, expected_version)
     end
 
     # Detect if browser is Sputnik.
     def sputnik?(expected_version = nil)
-      Sputnik.new(ua).match? && detect_version?(full_version, expected_version)
+      instance_of?(Sputnik) && detect_version?(full_version, expected_version)
     end
 
     # Detect if browser is Yandex.
     def yandex?(expected_version = nil)
-      Yandex.new(ua).match? && detect_version?(full_version, expected_version)
+      instance_of?(Yandex) && detect_version?(full_version, expected_version)
     end
-    alias_method :yandex_browser?, :yandex?
+    alias yandex_browser? yandex?
 
     # Detect if browser is UCBrowser.
     def uc_browser?(expected_version = nil)
-      UCBrowser.new(ua).match? &&
+      instance_of?(UCBrowser) &&
         detect_version?(full_version, expected_version)
     end
 
     # Detect if browser is Nokia S40 Ovi Browser.
     def nokia?(expected_version = nil)
-      Nokia.new(ua).match? && detect_version?(full_version, expected_version)
+      instance_of?(Nokia) && detect_version?(full_version, expected_version)
     end
 
     # Detect if browser is MicroMessenger.
     def micro_messenger?(expected_version = nil)
-      MicroMessenger.new(ua).match? &&
+      instance_of?(MicroMessenger) &&
         detect_version?(full_version, expected_version)
     end
 
-    alias_method :wechat?, :micro_messenger?
+    alias wechat? micro_messenger?
 
     def weibo?(expected_version = nil)
-      Weibo.new(ua).match? && detect_version?(full_version, expected_version)
+      instance_of?(Weibo) && detect_version?(full_version, expected_version)
     end
 
     def alipay?(expected_version = nil)
-      Alipay.new(ua).match? && detect_version?(full_version, expected_version)
+      instance_of?(Alipay) && detect_version?(full_version, expected_version)
     end
 
     # Detect if browser is Opera Mini.
@@ -210,29 +210,29 @@ module Browser
 
     # Detect if browser is Huawei.
     def huawei_browser?(expected_version = nil)
-      HuaweiBrowser.new(ua).match? &&
+      instance_of?(HuaweiBrowser) &&
         detect_version?(full_version, expected_version)
     end
 
     # Detect if browser is Xiaomi Miui.
     def miui_browser?(expected_version = nil)
-      MiuiBrowser.new(ua).match? &&
+      instance_of?(MiuiBrowser) &&
         detect_version?(full_version, expected_version)
     end
 
     # Detect if browser is Maxthon.
     def maxthon?(expected_version = nil)
-      Maxthon.new(ua).match? && detect_version?(full_version, expected_version)
+      instance_of?(Maxthon) && detect_version?(full_version, expected_version)
     end
 
     # Detect if browser is QQ.
     def qq?(expected_version = nil)
-      QQ.new(ua).match? && detect_version?(full_version, expected_version)
+      instance_of?(QQ) && detect_version?(full_version, expected_version)
     end
 
     # Detect if browser is Sougou.
     def sougou_browser?(expected_version = nil)
-      SougouBrowser.new(ua).match? &&
+      instance_of?(SougouBrowser) &&
         detect_version?(full_version, expected_version)
     end
 
@@ -241,6 +241,11 @@ module Browser
       ua.include?("GSA") && detect_version?(full_version, expected_version)
     end
 
+    # Detect if browser is Chromium-based.
+    def chromium_based?
+      false
+    end
+
     def webkit_full_version
       ua[%r{AppleWebKit/([\d.]+)}, 1] || "0.0"
     end
@@ -260,12 +265,17 @@ module Browser
 
     # Detect if the browser is Electron.
     def electron?(expected_version = nil)
-      Electron.new(ua).match? && detect_version?(full_version, expected_version)
+      instance_of?(Electron) && detect_version?(full_version, expected_version)
+    end
+
+    # Detect if the browser is Epiphany.
+    def epiphany?(expected_version = nil)
+      instance_of?(Epiphany) && detect_version?(full_version, expected_version)
     end
 
     private def validate_size(subject, input)
       actual_bytesize = input.bytesize
-      size_limit = Browser.public_send("#{subject}_size_limit")
+      size_limit = Browser.public_send(:"#{subject}_size_limit")
 
       return if actual_bytesize < size_limit
 
