@@ -4,7 +4,7 @@ module Browser
   class Bot
     class KeywordMatcher
       def self.call(ua, _browser)
-        ua =~ /crawl|fetch|search|monitoring|spider|bot/
+        ua.match?(/crawl|fetch|search|monitoring|spider|bot/)
       end
     end
   end
