@@ -3,7 +3,7 @@
 module Browser
   class Platform
     class IOS < Base
-      MATCHER = /(iPhone|iPad|iPod)/.freeze
+      MATCHER = /(iPhone|iPad|iPod|CriOS)/.freeze
       VERSION_MATCHER =
         /OS (?<major>\d+)_(?<minor>\d+)_?(?<patch>\d+)?/.freeze
 
