@@ -4,7 +4,7 @@ module Browser
   class Platform
     class Mac < Base
       def version
-        (ua[/Mac OS X\s*([0-9_\.]+)?/, 1] || "0").tr("_", ".")
+        (ua[/Mac OS X\s*([0-9_.]+)?/, 1] || "0").tr("_", ".")
       end
 
       def name
@@ -18,7 +18,7 @@ module Browser
       end
 
       def match?
-        ua =~ /Mac/
+        ua.include?("Mac")
       end
     end
   end
