@@ -1,4 +1,5 @@
 # frozen_string_literal: true
+
 module Browser
   def self.user_agents
     @user_agents ||= browser_user_agents
@@ -15,7 +16,9 @@ module Browser
   end
 
   def self.search_engine_user_agents
-    @search_engine_user_agents ||= YAML.load_file(Browser.root.join("test/ua_search_engines.yml"))
+    @search_engine_user_agents ||= YAML.load_file(
+      Browser.root.join("test/ua_search_engines.yml")
+    )
   end
 
   def self.[](key)
