@@ -8,7 +8,7 @@ class FacebookTest < Minitest::Test
 
     assert_equal "Facebook", browser.name
     assert browser.facebook?
-    assert :facebook, browser.id
+    assert_equal :facebook, browser.id
     assert_equal "135.0.0.45.90", browser.full_version
     assert_equal "135", browser.version
   end
@@ -18,7 +18,7 @@ class FacebookTest < Minitest::Test
 
     assert_equal "Facebook", browser.name
     assert browser.facebook?
-    assert :facebook, browser.id
+    assert_equal :facebook, browser.id
     assert_equal "AppleWebKit/605.1.15", browser.full_version
     assert_equal "AppleWebKit/605", browser.version
   end
@@ -28,7 +28,7 @@ class FacebookTest < Minitest::Test
 
     assert_equal "Facebook", browser.name
     assert browser.facebook?
-    assert :facebook, browser.id
+    assert_equal :facebook, browser.id
     assert_equal "214.0.0.43.83", browser.full_version
     assert_equal "214", browser.version
   end
