@@ -9,7 +9,6 @@ class IosTest < Minitest::Test
     assert_equal "Safari", browser.name
     assert browser.safari?
     assert browser.webkit?
-    assert browser.modern?
     assert browser.platform.ios?
     refute browser.platform.mac?
     assert_equal "3.0", browser.full_version
@@ -22,11 +21,16 @@ class IosTest < Minitest::Test
     assert_equal "Safari", browser.name
     assert browser.safari?
     assert browser.webkit?
-    assert browser.modern?
     assert_equal "5.0.1", browser.full_version
     assert_equal "5", browser.version
   end
 
+  test "detects chrome in desktop mode" do
+    browser = Browser.new(Browser["CHROME_REQUEST_DESKTOP_SITE"])
+    assert browser.platform.ios?
+    assert browser.device.mobile?
+  end
+
   test "detects safari in webapp mode" do
     browser = Browser.new(Browser["SAFARI_IPAD_WEBAPP_MODE"])
     refute browser.safari?
@@ -56,7 +60,6 @@ class IosTest < Minitest::Test
     assert_equal "Safari", browser.name
     assert browser.safari?
     assert browser.webkit?
-    assert browser.modern?
     assert browser.platform.ios?
     refute browser.platform.mac?
     assert_equal "4.0.4", browser.full_version
@@ -105,7 +108,14 @@ class IosTest < Minitest::Test
     refute browser.platform.mac?
   end
 
-  test "don't detect as two different versions" do
+  test "detects ios12" do
+    browser = Browser.new(Browser["IOS12"])
+    assert browser.platform.ios?
+    assert browser.platform.ios?(12)
+    refute browser.platform.mac?
+  end
+
+  test "does not detect as two different versions" do
     browser = Browser.new(Browser["IOS8"])
     assert browser.platform.ios?(8)
     refute browser.platform.ios?(7)
@@ -115,24 +125,22 @@ class IosTest < Minitest::Test
     browser = Browser.new(Browser["IPHONE"])
     meta = browser.to_s
 
-    assert meta.include?("webkit")
-    assert meta.include?("ios")
-    assert meta.include?("safari")
-    assert meta.include?("safari3")
-    assert meta.include?("modern")
-    assert meta.include?("mobile")
-    refute meta.include?("tablet")
+    assert_includes meta, "webkit"
+    assert_includes meta, "ios"
+    assert_includes meta, "safari"
+    assert_includes meta, "safari3"
+    assert_includes meta, "mobile"
+    refute_includes meta, "tablet"
   end
 
   test "returns string representation for ipad" do
     browser = Browser.new(Browser["IPAD"])
     meta = browser.to_s
 
-    assert meta.include?("webkit")
-    assert meta.include?("ios")
-    assert meta.include?("safari")
-    assert meta.include?("modern")
-    assert meta.include?("tablet")
-    refute meta.include?("mobile")
+    assert_includes meta, "webkit"
+    assert_includes meta, "ios"
+    assert_includes meta, "safari"
+    assert_includes meta, "tablet"
+    refute_includes meta, "mobile"
   end
 end
