@@ -1,4 +1,5 @@
 # frozen_string_literal: true
+
 require "test_helper"
 
 class ProxyTest < Minitest::Test
@@ -9,11 +10,11 @@ class ProxyTest < Minitest::Test
   ].each do |name|
     ua = Browser[name]
 
-    test "detect #{name} as proxy" do
+    test "detects #{name} as proxy" do
       browser = Browser.new(ua)
 
       assert browser.proxy?
-      assert browser.meta.include?("proxy")
+      assert_includes browser.meta, "proxy"
     end
   end
 end
