@@ -6,7 +6,7 @@ class UcBrowserTest < Minitest::Test
   test "detects UC Browser" do
     browser = Browser.new(Browser["UC_BROWSER"])
     assert browser.uc_browser?
-    assert_equal browser.name, "UCBrowser"
+    assert_equal "UCBrowser", browser.name
   end
 
   test "detects version by range" do
